@@ -15,73 +15,6 @@
 -- This is a suite of SQL helper functions for use during a PostGIS extension install/upgrade
 -- The functions get uninstalled after the extension install/upgrade process
 ---------------------------
--- postgis_extension_remove_objects: This function removes objects of a particular class from an extension
--- this is needed because there is no ALTER EXTENSION DROP FUNCTION/AGGREGATE command
--- and we can't CREATE OR REPLACE functions whose signatures have changed and we can drop them if they are part of an extension
--- So we use this to remove it from extension first before we drop
-CREATE FUNCTION postgis_extension_remove_objects(param_extension text, param_type text)
-  RETURNS boolean AS
-$$
-DECLARE
-	var_sql text := '';
-	var_r record;
-	var_result boolean := false;
-	var_class text := '';
-	var_is_aggregate boolean := false;
-	var_sql_list text := '';
-	var_pgsql_version integer := pg_catalog.current_setting('server_version_num');
-BEGIN
-		var_class := CASE WHEN pg_catalog.lower(param_type) OPERATOR(pg_catalog.=)'function' OR pg_catalog.lower(param_type) OPERATOR(pg_catalog.=) 'aggregate' THEN 'pg_catalog.pg_proc' ELSE '' END;
-		var_is_aggregate := CASE WHEN pg_catalog.lower(param_type) OPERATOR(pg_catalog.=) 'aggregate' THEN true ELSE false END;
-
-		IF var_pgsql_version OPERATOR(pg_catalog.<) 110000 THEN
-			var_sql_list := $sql$SELECT 'ALTER EXTENSION ' OPERATOR(pg_catalog.||)  e.extname OPERATOR(pg_catalog.||) ' DROP ' OPERATOR(pg_catalog.||) $3 OPERATOR(pg_catalog.||) ' ' OPERATOR(pg_catalog.||) COALESCE(proc.proname OPERATOR(pg_catalog.||) '(' OPERATOR(pg_catalog.||) oidvectortypes(proc.proargtypes) OPERATOR(pg_catalog.||) ')' ,typ.typname, cd.relname, op.oprname,
-					cs.typname OPERATOR(pg_catalog.||) ' AS ' OPERATOR(pg_catalog.||) ct.typname OPERATOR(pg_catalog.||) ') ', opcname, opfname) OPERATOR(pg_catalog.||) ';' AS remove_command
-			FROM pg_catalog.pg_depend As d INNER JOIN pg_catalog.pg_extension As e
-				ON d.refobjid OPERATOR(pg_catalog.=) e.oid INNER JOIN pg_catalog.pg_class As c ON
-					c.oid OPERATOR(pg_catalog.=) d.classid
-					LEFT JOIN pg_catalog.pg_proc AS proc ON proc.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_catalog.pg_type AS typ ON typ.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_catalog.pg_class As cd ON cd.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_operator As op ON op.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_catalog.pg_cast AS ca ON ca.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_catalog.pg_type AS cs ON ca.castsource OPERATOR(pg_catalog.=) cs.oid
-					LEFT JOIN pg_catalog.pg_type AS ct ON ca.casttarget OPERATOR(pg_catalog.=) ct.oid
-					LEFT JOIN pg_opclass As oc ON oc.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_opfamily As ofa ON ofa.oid OPERATOR(pg_catalog.=) d.objid
-			WHERE d.deptype OPERATOR(pg_catalog.=) 'e' and e.extname OPERATOR(pg_catalog.=) $1 and c.relname OPERATOR(pg_catalog.=) $2 AND COALESCE(proc.proisagg, false) OPERATOR(pg_catalog.=) $4;$sql$;
-		ELSE -- for PostgreSQL 11 and above, they removed proc.proisagg among others and replaced with some func type thing
-			var_sql_list := $sql$SELECT 'ALTER EXTENSION ' OPERATOR(pg_catalog.||) e.extname OPERATOR(pg_catalog.||) ' DROP ' OPERATOR(pg_catalog.||) $3 OPERATOR(pg_catalog.||) ' ' OPERATOR(pg_catalog.||) COALESCE(proc.proname OPERATOR(pg_catalog.||) '(' OPERATOR(pg_catalog.||) oidvectortypes(proc.proargtypes) OPERATOR(pg_catalog.||) ')' ,typ.typname, cd.relname, op.oprname,
-					cs.typname OPERATOR(pg_catalog.||) ' AS ' OPERATOR(pg_catalog.||) ct.typname OPERATOR(pg_catalog.||) ') ', opcname, opfname) OPERATOR(pg_catalog.||) ';' AS remove_command
-			FROM pg_catalog.pg_depend As d INNER JOIN pg_catalog.pg_extension As e
-				ON d.refobjid OPERATOR(pg_catalog.=) e.oid INNER JOIN pg_catalog.pg_class As c ON
-					c.oid OPERATOR(pg_catalog.=) d.classid
-					LEFT JOIN pg_catalog.pg_proc AS proc ON proc.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_catalog.pg_type AS typ ON typ.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_catalog.pg_class As cd ON cd.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_operator As op ON op.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_catalog.pg_cast AS ca ON ca.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_catalog.pg_type AS cs ON ca.castsource OPERATOR(pg_catalog.=) cs.oid
-					LEFT JOIN pg_catalog.pg_type AS ct ON ca.casttarget OPERATOR(pg_catalog.=) ct.oid
-					LEFT JOIN pg_opclass As oc ON oc.oid OPERATOR(pg_catalog.=) d.objid
-					LEFT JOIN pg_opfamily As ofa ON ofa.oid OPERATOR(pg_catalog.=) d.objid
-			WHERE d.deptype OPERATOR(pg_catalog.=) 'e' and e.extname OPERATOR(pg_catalog.=) $1 and c.relname OPERATOR(pg_catalog.=) $2 AND (proc.prokind OPERATOR(pg_catalog.=) 'a')  OPERATOR(pg_catalog.=) $4;$sql$;
-		END IF;
-
-		FOR var_r IN EXECUTE var_sql_list  USING param_extension, var_class, param_type, var_is_aggregate
-		LOOP
-			var_sql := var_sql OPERATOR(pg_catalog.||) var_r.remove_command OPERATOR(pg_catalog.||) ';';
-		END LOOP;
-		IF var_sql > '' THEN
-			EXECUTE var_sql;
-			var_result := true;
-		END IF;
-
-		RETURN var_result;
-END;
-$$
-LANGUAGE plpgsql VOLATILE;
-
 CREATE FUNCTION postgis_extension_drop_if_exists(param_extension text, param_statement text)
   RETURNS boolean AS
 $$
@@ -185,7 +118,7 @@ LANGUAGE 'plpgsql' VOLATILE STRICT
 
 
 --
--- UPGRADE SCRIPT TO PostGIS 3.6.1
+-- UPGRADE SCRIPT TO PostGIS 3.6.2
 --
 
 LOAD '$libdir/postgis_sfcgal-3';
@@ -203,7 +136,7 @@ DECLARE
 BEGIN
 
     old_scripts := postgis_scripts_installed();
-    new_scripts := '3.6.1';
+    new_scripts := '3.6.2';
 
     BEGIN
         new_ver_int := pg_catalog.string_to_array(
@@ -253,7 +186,7 @@ BEGIN
     END IF;
 
     WITH versions AS (
-      SELECT '3.6.1'::text as upgraded,
+      SELECT '3.6.2'::text as upgraded,
       postgis_scripts_installed() as installed
     ) SELECT
       upgraded as scripts_upgraded,
@@ -300,7 +233,7 @@ LANGUAGE 'plpgsql';
 
 
 CREATE OR REPLACE FUNCTION postgis_sfcgal_scripts_installed() RETURNS text
-	AS $$ SELECT trim('3.6.1'::text || $rev$ f533623 $rev$) AS version $$
+	AS $$ SELECT trim('3.6.2'::text || $rev$ 08d9b9f $rev$) AS version $$
 	LANGUAGE 'sql' IMMUTABLE;
 CREATE OR REPLACE FUNCTION postgis_sfcgal_version() RETURNS text
         AS '$libdir/postgis_sfcgal-3'
@@ -811,7 +744,6 @@ DROP FUNCTION _postgis_upgrade_info();
 --
 -- This drops extension helper functions
 -- and should be called at the end of the extension upgrade file
-DROP FUNCTION postgis_extension_remove_objects(text, text);
 DROP FUNCTION postgis_extension_drop_if_exists(text, text);
 DROP FUNCTION IF EXISTS postgis_extension_AddToSearchPath(varchar);
 DROP FUNCTION IF EXISTS postgis_extension_AddToSearchPath(text);
